# MySmallSite
my Small Site fw

## how2use

1. INSTALL
2. USE CLI

### INSTALLATION

1. `pip install MySmallSite` to install
2. THEN `MYSMALLSITE` MODULE IS WILL BE INSTALL ;)

### HOW 2 USE HELP IN CLI

 - `python -m MYSMALLSITE.gener --help`
 - `python -m MYSMALLSITE.psite`
